@@ -3,10 +3,11 @@ from importlib.resources import read_text
 from pybrary.command import Command
 
 from ..cmd.cmd import CommandCmd
-from ..cmd.deploy import  DeployCmd
-from ..cmd.manage import  ManageCmd
-from ..cmd.method import  MethodCmd
-from ..cmd.target import  TargetParam
+from ..cmd.action import ActionCmd
+from ..cmd.deploy import DeployCmd
+from ..cmd.manage import ManageCmd
+from ..cmd.method import MethodCmd
+from ..cmd.target import TargetParam
 from ..cmd.config import get_config, ConfigCmd
 from setux.repl.repl import repl
 
@@ -31,6 +32,7 @@ class MainCmd(Command):
     shortcut = True
     subs = dict(
         command = CommandCmd(),
+        action = ActionCmd(),
         deploy = DeployCmd(),
         manage = ManageCmd(),
         method = MethodCmd(),
