@@ -30,7 +30,7 @@ class Edit(Command):
     def run(self):
         target = self.get('target')
         remote = self.get('path')
-        sudo = self.get('sudo')
+        sudo = self.get('user')
         editor = environ.get('EDITOR','vim')
         dest = Path('/tmp/setux')
         dest.mkdir(exist_ok=True)
