@@ -12,7 +12,7 @@ class Repl(Cmd):
         self.command = command
         user = target.login.name
         host = target.system.hostname
-        self.prompt = f'{user}@{host} > '
+        self.prompt = f'{user}@{host}: '
         super().__init__()
 
     def do_help(self, line):
